# dj-active-campaign

## Overview

This project is intened to help django developers integrate ActiveCampaing's API endpoints to their django solution.

This project is still under development and currently only supports adding Custom Fields and Contacts.

